package oracle.toplink.essentials.platform.database;

import javax.persistence.GenerationType;

import oracle.toplink.essentials.platform.database.HSQLPlatform;
import oracle.toplink.essentials.queryframework.ValueReadQuery;
import oracle.toplink.essentials.sequencing.NativeSequence;
import oracle.toplink.essentials.sequencing.Sequence;
import oracle.toplink.essentials.sequencing.TableSequence;

/**
 * HSQLPlatform implementation that may be used with HSQL version 1.8.
 * 
 * This implementation supports the use of Sequence for PK generation
 *  
 * 
 * It's likely that this implementation may also be used with version 1.7.2, as this was
 * the version where the Sequence support was introduced. It has, however, not been tested
 * with HSQL 1.7.2
 * 
 * @see GenerationType#SEQUENCE
 * 
 * @author Morten Andersen-Gott (Accenture)
 *
 */
public class HSQL18SequencePlatform extends HSQLPlatform {


    /**
     * INTERNAL:
     * HSQL 1.8 supports both Sequences and Identity columns
     */
	@Override
    public boolean supportsNativeSequenceNumbers() {
        return true;
    }	
	

    /**
     * Taken from the HSQL Documentation:
     * 
     * Please note that the semantics of sequences is not exactly the same as defined by SQL 200n. 
     * For example if you use the same sequence twice in the same row insert query, 
     * you will get two different values, not the same value as required by the standard.
     * 
     * This should however not affect the usage in JPA
     */
	@Override
	public ValueReadQuery buildSelectQueryForNativeSequence(String seqName, Integer size) {
    	return new ValueReadQuery("SELECT NEXT VALUE FOR " + seqName + " FROM INFORMATION_SCHEMA.SYSTEM_SEQUENCES");
	}
	

}
